adaptive_liftover: adaptive_liftover

View source: R/adaptive_liftover.R

adaptive_liftoverR Documentation

adaptive_liftover

Description

Generate candidate target regions

Usage

adaptive_liftover(
  gr,
  chain,
  window = 2000L,
  option = "adaptive",
  gap = 5L,
  step_size = 200L,
  verbose = TRUE
)

Arguments

gr

The query regions of GRanges class.

chain

The chain object obtained from rtracklayer::import.chain().

window

The window size (bp) around the query regions. Default is 2000L.

option

The option for adaptive_liftover option = 'direct', apply direct liftOver to the query regions; option = 'local', apply local liftOver by extending the query regions by a window size; option = 'adaptive', apply direct liftOver first, for these failing to map, apply local liftOver.

gap

Ignore the gaps among target regions if below this value (bp). Default it 5L.

step_size

The step_size for generating candidate target regions. Default is 200L.

verbose

Print messages or not. Default is TRUE.

Value

The candidate target regions of GRangesList class with length equal to the query regions.

Author(s)

Chenyang Dong cdong@stat.wisc.edu

Examples


## Not run: 
data('data_example')
## the reciprocal chain file can be downloaded from UCSC
chain <- import.chain('mm10.hg38.rbest.chain')
gr_target_list <- adaptive_liftover(gr, chain, window = 2000, step_size = 10000)
gr_target_list <- adaptive_liftover(gr, chain, window = 2000, step_size = 200)

## End(Not run)



ThomasDCY/AdaLiftOver documentation built on June 2, 2025, 12:35 p.m.