compute_similarity_epigenome: compute_similarity_epigenome

View source: R/compute_similarity_epigenome.R

compute_similarity_epigenomeR Documentation

compute_similarity_epigenome

Description

This function computes the epigenome profile similarities between query regions and the corresponding list of target regions.

Usage

compute_similarity_epigenome(
  gr_query,
  gr_target_list,
  query_grlist,
  target_grlist,
  weights = NULL,
  maxgap = 500L,
  metric = "cosine",
  verbose = TRUE
)

Arguments

gr_query

The query genomic regions of GRanges class.

gr_target_list

The corresponding candidate target regions of GRangesList class. The length of gr_target_list should be the same as the length of gr_query

query_grlist

The epigenomic datasets in query genome, GRangesList class.

target_grlist

The epigenomic datasets in target genome, GRangesList class. Should match with query_grlist.

weights

The weights of epigenomic datasets. A numeric vector with length equal to the number of epigenomic datasets. Default is NULL (equal weights).

maxgap

The maxgap allowed for overlapping. Default is 500L.

metric

The metric for computing similarities between indicators. One of 'cosine' and 'jaccard'. Default is 'cosine'.

verbose

Print messages or not. Default is TRUE.

Value

A GRangesList class the same structure as gr_target_list with an extra meta column named "epigenome" measuring the similarity score of epigenome datasets.

Author(s)

Chenyang Dong cdong@stat.wisc.edu

Examples


## Not run: 
data('data_example')
## the epigenomic datasets in this example can be downloaded from github
gr_target_list <- compute_similarity_epigenome(gr, gr_list, epigenome_mm10, epigenome_hg38)

## End(Not run)



ThomasDCY/AdaLiftOver documentation built on June 2, 2025, 12:35 p.m.