compute_similarity_epigenome_flat: compute_similarity_epigenome_flat

View source: R/compute_similarity_epigenome.R

compute_similarity_epigenome_flatR Documentation

compute_similarity_epigenome_flat

Description

This function computes the epigenome profile similarities between query regions and the corresponding target regions.

Usage

compute_similarity_epigenome_flat(
  gr_query,
  gr_target,
  query_grlist,
  target_grlist,
  weights = NULL,
  maxgap = 500L,
  metric = "cosine"
)

Arguments

gr_query

The query genomic regions of GRanges class.

gr_target

The target genomic regions of GRanges class. The length of gr_target has to be equal to the length of gr_query. Or either gr_query or gr_target has length 1 that can be broadcasted.

query_grlist

The epigenomic datasets in query genome, GRangesList class.

target_grlist

The epigenomic datasets in target genome, GRangesList class. Should match with query_grlist.

weights

The weights of epigenomic datasets. A numeric vector with length equal to the number of epigenomic datasets. Default is NULL (equal weights).

maxgap

The maxgap allowed for overlapping. Default is 500L.

metric

The metric for computing similarities between indicators. One of 'cosine' and 'jaccard'. Default is 'cosine'.

Value

A numeric vector with values between 0 and 1.

Author(s)

Chenyang Dong cdong@stat.wisc.edu

Examples


## Not run: 
data('data_example')
## the epigenomic datasets in this example can be downloaded from github
similarity <- compute_similarity_epigenome_flat(gr[2], gr_list[[2]], epigenome_mm10, epigenome_hg38)

## End(Not run)


ThomasDCY/AdaLiftOver documentation built on June 2, 2025, 12:35 p.m.