gr_candidate_filter: gr_candidate_filter

View source: R/gr_candidate_filter.R

gr_candidate_filterR Documentation

gr_candidate_filter

Description

This function takes GRangesList with 'epigenome' and 'grammar' meta columns and filter the results based on these two columns.

Usage

gr_candidate_filter(
  gr_candidate,
  best_k = 1L,
  b_intercept = -4.1626668,
  b_epigenome = 5.4030573,
  b_grammar = 2.0649039,
  b_interaction = NULL,
  threshold = 0,
  random = FALSE,
  verbose = TRUE
)

Arguments

gr_candidate

A GRangesList object with 'epigenome' and 'grammar' meta columns.

best_k

Select the best k regions for each element of gr_candidate. Default is 1L.

b_intercept

The regression coefficient of intercept. Default is -4.1626668.

b_epigenome

The regression coefficient of epigenome similarity. Default is 5.4030573.

b_grammar

The regression coefficient of grammar similarity. Default is 2.0649039.

b_interaction

The regression coefficient of the interaction term. Default is NULL.

threshold

Discard the genomic regions with score below this threshold. Default is 0.

random

Pick best_k regions randomly for each element of gr_candidate. Default is FALSE.

verbose

Print messages or not. Default is TRUE.

Value

A GRangesList class the same structure as gr_candidate with an extra meta column named "score" measuring the overall similarity score. Any genomic regions with score below the threshold will be filtered away.

Author(s)

Chenyang Dong cdong@stat.wisc.edu

Examples


data('data_example')
gr_list_filtered <- gr_candidate_filter(gr_list_score, threshold = 0.5)



ThomasDCY/AdaLiftOver documentation built on June 2, 2025, 12:35 p.m.