training_module: training_module

View source: R/training_module.R

training_moduleR Documentation

training_module

Description

This function takes GRangesList with 'epigenome' and 'grammar' meta columns and evaluate the predictive power of overlapping with the true orthologous genomic regions.

Usage

training_module(
  gr_candidate,
  gr_true,
  max_filter_proportion = 0.4,
  interaction = FALSE
)

Arguments

gr_candidate

A GRangesList object with 'epigenome' and 'grammar' meta columns.

gr_true

A GRanges object as the true orthologous genomic regions that we aim to derive.

max_filter_proportion

The maximum proportion of candidate target regions that are allowed to be filtered out. Default is 0.4.

interaction

If we include the interaction term in the logistic regression. Default is FALSE.

Value

A data.table with the following columns:

auroc The optimal AUROC.
aupr The optimal AUPR.
b.intercept The estimated regression coefficient for the intercept.
b.epigenome The estimated regression coefficient for the epigenome signal.
b.grammar The estimated regression coefficient for the sequence grammar.
b.interaction The estimated regression coefficient for the interaction term if included.
max_filter_proportion The input parameter max_filter_proportion.
threshold The suggested score threshold.
precision The precision associated with the suggested score threshold.

Author(s)

Chenyang Dong cdong@stat.wisc.edu

Examples


data('training_module_example')
res <- training_module(gr_candidate, gr_true)



ThomasDCY/AdaLiftOver documentation built on June 2, 2025, 12:35 p.m.