View source: R/adaptive_liftover.R
| adaptive_liftover | R Documentation |
Generate candidate target regions
adaptive_liftover(
gr,
chain,
window = 2000L,
option = "adaptive",
gap = 5L,
step_size = 200L,
verbose = TRUE
)
gr |
The query regions of |
chain |
The chain object obtained from |
window |
The window size (bp) around the query regions. Default is 2000L. |
option |
The option for adaptive_liftover option = 'direct', apply direct liftOver to the query regions; option = 'local', apply local liftOver by extending the query regions by a window size; option = 'adaptive', apply direct liftOver first, for these failing to map, apply local liftOver. |
gap |
Ignore the gaps among target regions if below this value (bp). Default it 5L. |
step_size |
The step_size for generating candidate target regions. Default is 200L. |
verbose |
Print messages or not. Default is TRUE. |
The candidate target regions of GRangesList class with
length equal to the query regions.
Chenyang Dong cdong@stat.wisc.edu
## Not run:
data('data_example')
## the reciprocal chain file can be downloaded from UCSC
chain <- import.chain('mm10.hg38.rbest.chain')
gr_target_list <- adaptive_liftover(gr, chain, window = 2000, step_size = 10000)
gr_target_list <- adaptive_liftover(gr, chain, window = 2000, step_size = 200)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.