View source: R/compute_similarity_epigenome.R
| compute_similarity_epigenome_flat | R Documentation |
This function computes the epigenome profile similarities between query regions and the corresponding target regions.
compute_similarity_epigenome_flat(
gr_query,
gr_target,
query_grlist,
target_grlist,
weights = NULL,
maxgap = 500L,
metric = "cosine"
)
gr_query |
The query genomic regions of |
gr_target |
The target genomic regions of |
query_grlist |
The epigenomic datasets in query genome, |
target_grlist |
The epigenomic datasets in target genome, |
weights |
The weights of epigenomic datasets. A numeric vector with length equal to the number of epigenomic datasets. Default is NULL (equal weights). |
maxgap |
The maxgap allowed for overlapping. Default is 500L. |
metric |
The metric for computing similarities between indicators. One of 'cosine' and 'jaccard'. Default is 'cosine'. |
A numeric vector with values between 0 and 1.
Chenyang Dong cdong@stat.wisc.edu
## Not run:
data('data_example')
## the epigenomic datasets in this example can be downloaded from github
similarity <- compute_similarity_epigenome_flat(gr[2], gr_list[[2]], epigenome_mm10, epigenome_hg38)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.