View source: R/compute_similarity_grammar.R
| compute_similarity_grammar | R Documentation |
This function computes the sequence grammar similarities between query regions and the corresponding list of target regions.
compute_similarity_grammar(
gr_query,
gr_target_list,
query_genome,
target_genome,
motif_list,
grammar_size = 500L,
metric = "cosine",
verbose = TRUE
)
gr_query |
The query genomic regions of |
gr_target_list |
The corresponding candidate target regions of |
query_genome |
The query genome build identifier (e.g. 'mm10', 'hg38').
Make sure the corresponding BSgenome package is installed.
Or a |
target_genome |
The target genome build identifier (e.g. 'mm10', 'hg38').
Make sure the corresponding BSgenome package is installed.
Or a |
motif_list |
|
grammar_size |
The nearby region (bp) to extract regulatory grammars. Default is 500L. |
metric |
The metric for computing similarities between indicators. One of 'cosine' and 'jaccard'. Default is 'cosine'. |
verbose |
Print messages or not. Default is TRUE. |
A GRangesList class the same structure as gr_target_list
with an extra meta column named "grammar" measuring the similarity score of sequence grammars.
Chenyang Dong cdong@stat.wisc.edu
data('data_example')
data('jaspar_pfm_list')
gr_target_list <- compute_similarity_grammar(gr, gr_list, 'mm10', 'hg38', jaspar_pfm_list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.