View source: R/gr_candidate_filter.R
| gr_candidate_filter | R Documentation |
This function takes GRangesList with 'epigenome' and 'grammar' meta columns and filter the results based on these two columns.
gr_candidate_filter(
gr_candidate,
best_k = 1L,
b_intercept = -4.1626668,
b_epigenome = 5.4030573,
b_grammar = 2.0649039,
b_interaction = NULL,
threshold = 0,
random = FALSE,
verbose = TRUE
)
gr_candidate |
A |
best_k |
Select the best k regions for each element of gr_candidate. Default is 1L. |
b_intercept |
The regression coefficient of intercept. Default is -4.1626668. |
b_epigenome |
The regression coefficient of epigenome similarity. Default is 5.4030573. |
b_grammar |
The regression coefficient of grammar similarity. Default is 2.0649039. |
b_interaction |
The regression coefficient of the interaction term. Default is NULL. |
threshold |
Discard the genomic regions with score below this threshold. Default is 0. |
random |
Pick best_k regions randomly for each element of gr_candidate. Default is FALSE. |
verbose |
Print messages or not. Default is TRUE. |
A GRangesList class the same structure as gr_candidate
with an extra meta column named "score" measuring the overall similarity score.
Any genomic regions with score below the threshold will be filtered away.
Chenyang Dong cdong@stat.wisc.edu
data('data_example')
gr_list_filtered <- gr_candidate_filter(gr_list_score, threshold = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.