View source: R/training_module.R
| training_module | R Documentation |
This function takes GRangesList with 'epigenome' and 'grammar' meta columns and evaluate the predictive power of overlapping with the true orthologous genomic regions.
training_module(
gr_candidate,
gr_true,
max_filter_proportion = 0.4,
interaction = FALSE
)
gr_candidate |
A |
gr_true |
A |
max_filter_proportion |
The maximum proportion of candidate target regions that are allowed to be filtered out. Default is 0.4. |
interaction |
If we include the interaction term in the logistic regression. Default is FALSE. |
A data.table with the following columns:
auroc | The optimal AUROC. |
aupr | The optimal AUPR. |
b.intercept | The estimated regression coefficient for the intercept. |
b.epigenome | The estimated regression coefficient for the epigenome signal. |
b.grammar | The estimated regression coefficient for the sequence grammar. |
b.interaction | The estimated regression coefficient for the interaction term if included. |
max_filter_proportion | The input parameter max_filter_proportion. |
threshold | The suggested score threshold. |
precision | The precision associated with the suggested score threshold. |
Chenyang Dong cdong@stat.wisc.edu
data('training_module_example')
res <- training_module(gr_candidate, gr_true)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.